ui = shinyUI(
  fluidPage(
    titlePanel("Data Summarizer"),        # Title
    sidebarLayout(
      sidebarPanel(
        h3("Data Selection"),             # Note the , 
        
        # Dropdown
        selectInput("ds",                 # Name
                    "Choose a dataset:",  # Label
                    choices = c("iris", "Spam", "mtcars")),
        
        numericInput("obs",               # Name
                     "Number of Obs:",    # Label
                     10),                 # Default Value
        
        submitButton("Load Preview Data") # Update data
      ), # close: sidebarPanel()
      mainPanel(
        h3("Head of the Dataset"),    # HTML
        tableOutput("view"),          # Table View
        
        h3("Dataset Summary"),        # HTML
        verbatimTextOutput("summary") # Output Asis
      ) # close: mainPanel()
    ) # close: sidebarLayout()
  )) # close: shinyUI(fluidPage(


server = shinyServer(function(input, output) {
  
  dsInput = reactive({   # Reactive
    if(input$ds == "iris") {
      iris
    } else if (input$ds == "Spam") {
      Spam
    } else {
      mtcars
    }
  }) # close: reactive()
  
  output$summary = renderPrint({   # Summary Render
    summary(dsInput())
  }) # close: renderPrint()
  
  output$view = renderTable({      # Table Render
    head(dsInput(), n = input$obs)
  }) # close: renderPrint()
  
}) # close: shinyServer()

shinyApp(ui = ui, server = server)